CacheConfigBuilder

Struct CacheConfigBuilder 

pub struct CacheConfigBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> CacheConfigBuilder<S>

pub fn build(self) -> CacheConfig
where S: IsComplete,

Finish building and return the requested object

pub fn database( self, value: DatabaseConfig, ) -> CacheConfigBuilder<SetDatabase<S>>
where S::Database: IsUnset,

Optional (Some / Option setters). The configuration for the cache backing database.

pub fn maybe_database( self, value: Option<DatabaseConfig>, ) -> CacheConfigBuilder<SetDatabase<S>>
where S::Database: IsUnset,

Optional (Some / Option setters). The configuration for the cache backing database.

pub fn encoding( self, value: SerializationEncoding, ) -> CacheConfigBuilder<SetEncoding<S>>
where S::Encoding: IsUnset,

Optional (Some / Option setters). Default: SerializationEncoding::MsgPack.

The encoding for database operations, controls the type of serializer used.

pub fn maybe_encoding( self, value: Option<SerializationEncoding>, ) -> CacheConfigBuilder<SetEncoding<S>>
where S::Encoding: IsUnset,

Optional (Some / Option setters). Default: SerializationEncoding::MsgPack.

The encoding for database operations, controls the type of serializer used.

pub fn timestamps_as_iso8601( self, value: bool, ) -> CacheConfigBuilder<SetTimestampsAsIso8601<S>>
where S::TimestampsAsIso8601: IsUnset,

Optional (Some / Option setters). Default: false.

If timestamps should be persisted as ISO 8601 strings.

pub fn maybe_timestamps_as_iso8601( self, value: Option<bool>, ) -> CacheConfigBuilder<SetTimestampsAsIso8601<S>>
where S::TimestampsAsIso8601: IsUnset,

Optional (Some / Option setters). Default: false.

If timestamps should be persisted as ISO 8601 strings.

pub fn buffer_interval_ms( self, value: usize, ) -> CacheConfigBuilder<SetBufferIntervalMs<S>>
where S::BufferIntervalMs: IsUnset,

Optional (Some / Option setters). The buffer interval (milliseconds) between pipelined/batched transactions.

pub fn maybe_buffer_interval_ms( self, value: Option<usize>, ) -> CacheConfigBuilder<SetBufferIntervalMs<S>>
where S::BufferIntervalMs: IsUnset,

Optional (Some / Option setters). The buffer interval (milliseconds) between pipelined/batched transactions.

pub fn bulk_read_batch_size( self, value: usize, ) -> CacheConfigBuilder<SetBulkReadBatchSize<S>>
where S::BulkReadBatchSize: IsUnset,

Optional (Some / Option setters). The batch size for bulk read operations (e.g., MGET). If set, bulk reads will be batched into chunks of this size.

pub fn maybe_bulk_read_batch_size( self, value: Option<usize>, ) -> CacheConfigBuilder<SetBulkReadBatchSize<S>>
where S::BulkReadBatchSize: IsUnset,

Optional (Some / Option setters). The batch size for bulk read operations (e.g., MGET). If set, bulk reads will be batched into chunks of this size.

pub fn use_trader_prefix( self, value: bool, ) -> CacheConfigBuilder<SetUseTraderPrefix<S>>
where S::UseTraderPrefix: IsUnset,

Optional (Some / Option setters). Default: true.

If a ‘trader-’ prefix is used for keys.

pub fn maybe_use_trader_prefix( self, value: Option<bool>, ) -> CacheConfigBuilder<SetUseTraderPrefix<S>>
where S::UseTraderPrefix: IsUnset,

Optional (Some / Option setters). Default: true.

If a ‘trader-’ prefix is used for keys.

pub fn use_instance_id( self, value: bool, ) -> CacheConfigBuilder<SetUseInstanceId<S>>
where S::UseInstanceId: IsUnset,

Optional (Some / Option setters). Default: false.

If the trader’s instance ID is used for keys.

pub fn maybe_use_instance_id( self, value: Option<bool>, ) -> CacheConfigBuilder<SetUseInstanceId<S>>
where S::UseInstanceId: IsUnset,

Optional (Some / Option setters). Default: false.

If the trader’s instance ID is used for keys.

pub fn flush_on_start( self, value: bool, ) -> CacheConfigBuilder<SetFlushOnStart<S>>
where S::FlushOnStart: IsUnset,

Optional (Some / Option setters). Default: false.

If the database should be flushed on start.

pub fn maybe_flush_on_start( self, value: Option<bool>, ) -> CacheConfigBuilder<SetFlushOnStart<S>>
where S::FlushOnStart: IsUnset,

Optional (Some / Option setters). Default: false.

If the database should be flushed on start.

pub fn drop_instruments_on_reset( self, value: bool, ) -> CacheConfigBuilder<SetDropInstrumentsOnReset<S>>
where S::DropInstrumentsOnReset: IsUnset,

Optional (Some / Option setters). Default: true.

If instrument data should be dropped from the cache’s memory on reset.

pub fn maybe_drop_instruments_on_reset( self, value: Option<bool>, ) -> CacheConfigBuilder<SetDropInstrumentsOnReset<S>>
where S::DropInstrumentsOnReset: IsUnset,

Optional (Some / Option setters). Default: true.

If instrument data should be dropped from the cache’s memory on reset.

pub fn tick_capacity( self, value: usize, ) -> CacheConfigBuilder<SetTickCapacity<S>>
where S::TickCapacity: IsUnset,

Optional (Some / Option setters). Default: 10_000.

The maximum length for internal tick deques.

pub fn maybe_tick_capacity( self, value: Option<usize>, ) -> CacheConfigBuilder<SetTickCapacity<S>>
where S::TickCapacity: IsUnset,

Optional (Some / Option setters). Default: 10_000.

The maximum length for internal tick deques.

pub fn bar_capacity(self, value: usize) -> CacheConfigBuilder<SetBarCapacity<S>>
where S::BarCapacity: IsUnset,

Optional (Some / Option setters). Default: 10_000.

The maximum length for internal bar deques.

pub fn maybe_bar_capacity( self, value: Option<usize>, ) -> CacheConfigBuilder<SetBarCapacity<S>>
where S::BarCapacity: IsUnset,

Optional (Some / Option setters). Default: 10_000.

The maximum length for internal bar deques.

pub fn save_market_data( self, value: bool, ) -> CacheConfigBuilder<SetSaveMarketData<S>>
where S::SaveMarketData: IsUnset,

Optional (Some / Option setters). Default: false.

If market data should be persisted to disk.

pub fn maybe_save_market_data( self, value: Option<bool>, ) -> CacheConfigBuilder<SetSaveMarketData<S>>
where S::SaveMarketData: IsUnset,

Optional (Some / Option setters). Default: false.

If market data should be persisted to disk.