pub struct CacheConfig {
pub encoding: SerializationEncoding,
pub timestamps_as_iso8601: bool,
pub buffer_interval_ms: Option<usize>,
pub bulk_read_batch_size: Option<usize>,
pub use_trader_prefix: bool,
pub use_instance_id: bool,
pub flush_on_start: bool,
pub drop_instruments_on_reset: bool,
pub tick_capacity: usize,
pub bar_capacity: usize,
pub persist_account_events: bool,
pub save_market_data: bool,
}Expand description
Configuration for Cache instances.
Fields
encoding: SerializationEncodingThe encoding for database operations, controls the type of serializer used.
timestamps_as_iso8601: boolIf timestamps should be persisted as ISO 8601 strings.
buffer_interval_ms: Option<usize>The buffer interval (milliseconds) between pipelined/batched transactions.
bulk_read_batch_size: Option<usize>The batch size for bulk read operations (e.g., MGET). If set, bulk reads will be batched into chunks of this size.
use_trader_prefix: boolIf a ‘trader-’ prefix is used for keys.
use_instance_id: boolIf the trader’s instance ID is used for keys.
flush_on_start: boolIf the database should be flushed on start.
drop_instruments_on_reset: boolIf instrument data should be dropped from the cache’s memory on reset.
tick_capacity: usizeThe maximum length for internal tick deques.
bar_capacity: usizeThe maximum length for internal bar deques.
persist_account_events: boolIf account events should be persisted to a backing database.
save_market_data: boolIf market data should be persisted to disk.
Implementations
Sourceimpl CacheConfig
impl CacheConfig
Sourcepub fn builder() -> CacheConfigBuilder
pub fn builder() -> CacheConfigBuilder
Create an instance of CacheConfig using the builder syntax
Sourceimpl CacheConfig
impl CacheConfig
Sourcepub fn new(
encoding: SerializationEncoding,
timestamps_as_iso8601: bool,
buffer_interval_ms: Option<usize>,
bulk_read_batch_size: Option<usize>,
use_trader_prefix: bool,
use_instance_id: bool,
flush_on_start: bool,
drop_instruments_on_reset: bool,
tick_capacity: usize,
bar_capacity: usize,
persist_account_events: bool,
save_market_data: bool,
) -> Self
pub fn new( encoding: SerializationEncoding, timestamps_as_iso8601: bool, buffer_interval_ms: Option<usize>, bulk_read_batch_size: Option<usize>, use_trader_prefix: bool, use_instance_id: bool, flush_on_start: bool, drop_instruments_on_reset: bool, tick_capacity: usize, bar_capacity: usize, persist_account_events: bool, save_market_data: bool, ) -> Self
Sourcepub fn validate(&self) -> ConfigResult<()>
pub fn validate(&self) -> ConfigResult<()>
Checks whether all cache settings are valid.
Errors
Returns a ConfigError if a capacity setting is not positive.