CacheConfig

Struct CacheConfig 

pub struct CacheConfig {
Show 13 fields pub database: Option<DatabaseConfig>, pub encoding: SerializationEncoding, pub timestamps_as_iso8601: bool, pub buffer_interval_ms: Option<usize>, pub bulk_read_batch_size: Option<usize>, pub use_trader_prefix: bool, pub use_instance_id: bool, pub flush_on_start: bool, pub drop_instruments_on_reset: bool, pub tick_capacity: usize, pub bar_capacity: usize, pub persist_account_events: bool, pub save_market_data: bool,
}
Configuration for Cache instances.

Fields

database: Option<DatabaseConfig>

The configuration for the cache backing database.

encoding: SerializationEncoding

The encoding for database operations, controls the type of serializer used.

timestamps_as_iso8601: bool

If timestamps should be persisted as ISO 8601 strings.

buffer_interval_ms: Option<usize>

The buffer interval (milliseconds) between pipelined/batched transactions.

bulk_read_batch_size: Option<usize>

The batch size for bulk read operations (e.g., MGET). If set, bulk reads will be batched into chunks of this size.

use_trader_prefix: bool

If a ‘trader-’ prefix is used for keys.

use_instance_id: bool

If the trader’s instance ID is used for keys.

flush_on_start: bool

If the database should be flushed on start.

drop_instruments_on_reset: bool

If instrument data should be dropped from the cache’s memory on reset.

tick_capacity: usize

The maximum length for internal tick deques.

bar_capacity: usize

The maximum length for internal bar deques.

persist_account_events: bool

If account events should be persisted to a backing database.

save_market_data: bool

If market data should be persisted to disk.

Implementations

Source

impl CacheConfig

pub fn builder() -> CacheConfigBuilder

Create an instance of CacheConfig using the builder syntax

Source

impl CacheConfig

pub fn new( database: Option<DatabaseConfig>, encoding: SerializationEncoding, timestamps_as_iso8601: bool, buffer_interval_ms: Option<usize>, bulk_read_batch_size: Option<usize>, use_trader_prefix: bool, use_instance_id: bool, flush_on_start: bool, drop_instruments_on_reset: bool, tick_capacity: usize, bar_capacity: usize, persist_account_events: bool, save_market_data: bool, ) -> Self

Creates a new CacheConfig instance.

Panics

Panics if tick_capacity or bar_capacity is zero.

pub fn validate(&self) -> Result<()>

Checks whether all cache settings are valid.

Errors

Returns an error if a capacity setting is not positive.