#[repr(C)]pub struct QueueStateChanged {
pub trader_id: TraderId,
pub channel: SystemChannel,
pub condition: QueueCondition,
pub state: QueueState,
pub queue_depth: usize,
pub mean_dispatch_ns: u64,
pub event_id: UUID4,
pub ts_event: UnixNanos,
pub ts_init: UnixNanos,
}Expand description
Represents an event where a runner queue pressure condition has changed.
Fields
trader_id: TraderIdThe trader ID associated with the event.
channel: SystemChannelThe runner channel associated with the condition.
condition: QueueConditionThe queue pressure condition.
state: QueueStateThe condition state.
queue_depth: usizeThe queue depth at the state transition.
mean_dispatch_ns: u64The mean dispatch time per message at the state transition, in nanoseconds.
event_id: UUID4The event ID.
ts_event: UnixNanosUNIX timestamp (nanoseconds) when the event occurred.
ts_init: UnixNanosUNIX timestamp (nanoseconds) when the instance was initialized.
Implementations
Sourceimpl QueueStateChanged
impl QueueStateChanged
Sourcepub const fn new(
trader_id: TraderId,
channel: SystemChannel,
condition: QueueCondition,
state: QueueState,
queue_depth: usize,
mean_dispatch_ns: u64,
event_id: UUID4,
ts_event: UnixNanos,
ts_init: UnixNanos,
) -> Self
pub const fn new( trader_id: TraderId, channel: SystemChannel, condition: QueueCondition, state: QueueState, queue_depth: usize, mean_dispatch_ns: u64, event_id: UUID4, ts_event: UnixNanos, ts_init: UnixNanos, ) -> Self
Creates a new QueueStateChanged instance.
pub fn as_any(&self) -> &dyn Any